@@ -8,7 +8,7 @@ use JSON;
 use Role::Basic qw/with/;
 use Sys::Cmd qw/spawn/;
 
-our $VERSION = '0.1.0_21';
+our $VERSION = '0.1.0_22';
 
 with 'Bif::Role::Sync';
 
@@ -19,10 +19,9 @@ has db => (
 
 has debug => ( is => 'ro' );
 
-has hub => (
-    is       => 'ro',
-    required => 1,
-);
+has location => ( is => 'ro', );
+
+has hub_id => ( is => 'rw', );
 
 has child => ( is => 'rw' );
 
@@ -52,7 +51,7 @@ has on_error => ( is => 'ro', required => 1 );
 sub BUILD {
     my $self = shift;
 
-    if ( $self->hub =~ m!^ssh://(.+)! ) {
+    if ( $self->location =~ m!^ssh://(.+)! ) {
         $self->child(
             spawn( 'ssh', $1, 'bifsync', $self->debug_bs ? '--debug' : (), ) );
     }
@@ -61,11 +60,20 @@ sub BUILD {
             spawn(
                   'bifsync', $self->debug_bs
                 ? '--debug'
-                : (), $self->hub
+                : (),
+                $self->location
             )
         );
     }
 
+    $self->hub_id(
+        $self->db->xarray(
+            select => 'hl.hub_id',
+            from   => 'hub_locations hl',
+            where  => { 'hl.location' => $self->location },
+        )
+    );
+
     $self->child_watcher(
         AE::child $self->child->pid,
         sub {
@@ -97,7 +105,7 @@ sub register {
 
 sub sync_hub {
     my $self = shift;
-    my $id   = shift;
+    my $id = shift || die 'sync_hub($id)';
 
     my $hub = $self->db->xhash(
         select     => [ 'h.hash', 't.uuid' ],
@@ -164,11 +172,11 @@ sub sync_project {
     my $id   = shift;
 
     my $project = $self->db->xhash(
-        select     => [ 'p.hash', 't.uuid' ],
-        from       => 'projects p',
+        select     => [ 'hrp.hash', 't.uuid' ],
+        from       => 'hub_related_projects hrp',
         inner_join => 'topics t',
-        on         => 't.id = p.id',
-        where => { 'p.id' => $id },
+        on    => { 't.id'           => $id, },
+        where => { 'hrp.project_id' => $id, 'hrp.hub_id' => $self->hub_id, },
     );
 
     $self->write( 'SYNC', 'project', $project->{uuid}, $project->{hash} );
@@ -211,3 +219,126 @@ sub disconnect {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Bif::Client - client for communication with a bif hub
+
+=head1 VERSION
+
+0.1.0_22 (2014-05-10)
+
+=head1 SYNOPSIS
+
+    use strict;
+    use warnings;
+    use AnyEvent;
+    use App::bif::Context;
+    use Bif::Client;
+
+    my $ctx = App::bif::Context->new( {} );
+    my $client = Bif::Client->new(
+        db       => $ctx->dbw,
+        location => $LOCATION,
+    );
+
+    # Bif::Client is a Coro::Handle user so you want
+    # to do things inside a coroutine
+    async {
+        $client->register;
+    };
+
+    AnyEvent->condvar->recv;
+
+=head1 DESCRIPTION
+
+B<Bif::Client> is a class for communicating with a bif hub.
+
+=head1 CONSTRUCTOR
+
+=over 4
+
+=item Bif::Client->new( db => $dbh, hub => $location )
+
+=back
+
+=head1 ATTRIBUTES
+
+=over 4
+
+=item db
+
+=item debug
+
+=item child
+
+=item child_watcher
+
+=item debug_bs
+
+=item hub_id
+
+=item location
+
+=item updates_sent
+
+=item updates_recv
+
+=item on_update
+
+=item rh
+
+=item wh
+
+=item json
+
+=item on_error
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+
+=item register
+
+
+=item sync_hub($hub_id)
+
+Compares the C<hub_related_updates> table in the local repository
+against the same table on the hub and exchanges updates until they are
+the same. This method only results in project-only updates.
+
+=item import_project
+
+
+=item sync_project
+
+
+=item export_project
+
+
+=item disconnect
+
+=back
+
+=head1 SEE ALSO
+
+L<Bif::Server>
+
+=head1 AUTHOR
+
+Mark Lawrence E<lt>nomad@null.netE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2014 Mark Lawrence <nomad@null.net>
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
+
