@@ -1,8 +1,9 @@
 CREATE TABLE func_import_hub_update(
     update_uuid VARCHAR(40) NOT NULL,
     hub_uuid VARCHAR(40) NOT NULL,
-    related_update_uuid VARCHAR(40),
-    default_location_uuid VARCHAR(40)
+    default_location_uuid VARCHAR(40),
+    project_uuid VARCHAR(40),
+    related_update_uuid VARCHAR(40)
 );
 
 CREATE TRIGGER
@@ -15,22 +16,25 @@ BEGIN
     SELECT debug(
         NEW.update_uuid,
         NEW.hub_uuid,
-        NEW.related_update_uuid,
-        NEW.default_location_uuid
+        NEW.default_location_uuid,
+        NEW.project_uuid,
+        NEW.related_update_uuid
     );
 
     INSERT INTO
         hub_updates(
             update_id,
             hub_id,
-            related_update_uuid,
-            default_location_id
+            default_location_id,
+            project_id,
+            related_update_uuid
         )
     SELECT
         u.id,
         hubs.id,
-        NEW.related_update_uuid,
-        hl.id
+        hl.id,
+        p.id,
+        NEW.related_update_uuid
     FROM
         topics AS hubs
     INNER JOIN
@@ -41,6 +45,10 @@ BEGIN
         topics hl
     ON
         hl.uuid = NEW.default_location_uuid
+    LEFT JOIN
+        topics p
+    ON
+        p.uuid = NEW.project_uuid
     WHERE
         hubs.uuid = NEW.hub_uuid
     ;
